@@ -1,15 +1,7 @@
-// log4cpp logging facility
-#include "log4cpp/Category.hh"
-#include "log4cpp/Appender.hh"
-#include "log4cpp/FileAppender.hh"
-#include "log4cpp/OstreamAppender.hh"
-#include "log4cpp/Layout.hh"
-#include "log4cpp/BasicLayout.hh"
-#include "log4cpp/PatternLayout.hh"
-#include "log4cpp/Priority.hh"
+#include "../all_logcpp_libraries.h"
 
-#include <boost/version.hpp>
 #include <boost/algorithm/string.hpp>
+#include <boost/version.hpp>
 
 #include "../fast_library.h"
 
@@ -17,18 +9,18 @@
 #include <sys/types.h>
 
 // For config map operations
-#include <string>
 #include <map>
+#include <string>
 
-#include <stdio.h>
 #include <iostream>
+#include <stdio.h>
 #include <string>
 #define NETMAP_WITH_LIBS
 
 // Disable debug messages from Netmap
 #define NETMAP_NO_DEBUG
-#include <net/netmap_user.h>
 #include <boost/thread.hpp>
+#include <net/netmap_user.h>
 
 #if defined(__FreeBSD__)
 // On FreeBSD function pthread_attr_setaffinity_np declared here
@@ -46,9 +38,9 @@ typedef cpuset_t cpu_set_t;
 #include <poll.h>
 
 // For support: IPPROTO_TCP, IPPROTO_ICMP, IPPROTO_UDP
-#include <sys/types.h>
-#include <sys/socket.h>
 #include <netinet/in.h>
+#include <sys/socket.h>
+#include <sys/types.h>
 
 #include "netmap_collector.h"
 
@@ -84,11 +76,11 @@ int receive_packets(struct netmap_ring* ring, int thread_number) {
     u_int cur, rx, n;
 
     cur = ring->cur;
-    n = nm_ring_space(ring);
+    n   = nm_ring_space(ring);
 
     for (rx = 0; rx < n; rx++) {
         struct netmap_slot* slot = &ring->slot[cur];
-        char* p = NETMAP_BUF(ring, slot->buf_idx);
+        char* p                  = NETMAP_BUF(ring, slot->buf_idx);
 
         // process data
         consume_pkt((u_char*)p, slot->len, thread_number);
@@ -102,7 +94,7 @@ int receive_packets(struct netmap_ring* ring, int thread_number) {
 
 void consume_pkt(u_char* buffer, int len, int thread_number) {
     // We should fill this structure for passing to FastNetMon
-    simple_packet packet;
+    simple_packet_t packet;
 
     packet.sample_ratio = netmap_sampling_ratio;
 
@@ -110,7 +102,7 @@ void consume_pkt(u_char* buffer, int len, int thread_number) {
         total_unparsed_packets++;
 
         return;
-    }   
+    }
 
     netmap_process_func_ptr(packet);
 }
@@ -125,7 +117,7 @@ void receiver(std::string interface_for_listening) {
     base_nmd.nr_tx_rings = base_nmd.nr_rx_rings = 0;
     base_nmd.nr_tx_slots = base_nmd.nr_rx_slots = 0;
 
-    std::string interface = "";
+    std::string interface             = "";
     std::string system_interface_name = "";
     // If we haven't netmap: prefix in interface name we will append it
     if (interface_for_listening.find("netmap:") == std::string::npos) {
@@ -140,8 +132,10 @@ void receiver(std::string interface_for_listening) {
     }
 
 #ifdef __linux__
-    manage_interface_promisc_mode(system_interface_name, true); 
-    logger.warn("Please disable all types of offload for this NIC manually: ethtool -K %s gro off gso off tso off lro off", system_interface_name.c_str());
+    manage_interface_promisc_mode(system_interface_name, true);
+    logger.warn("Please disable all types of offload for this NIC manually: ethtool -K %s gro off "
+                "gso off tso off lro off",
+                system_interface_name.c_str());
 #endif
 
     netmap_descriptor = nm_open(interface.c_str(), &base_nmd, 0, NULL);
@@ -152,8 +146,7 @@ void receiver(std::string interface_for_listening) {
     }
 
     logger.info("Mapped %dKB memory at %p", netmap_descriptor->req.nr_memsize >> 10, netmap_descriptor->mem);
-    logger.info("We have %d tx and %d rx rings", netmap_descriptor->req.nr_tx_rings,
-                netmap_descriptor->req.nr_rx_rings);
+    logger.info("We have %d tx and %d rx rings", netmap_descriptor->req.nr_tx_rings, netmap_descriptor->req.nr_rx_rings);
 
     if (num_cpus > netmap_descriptor->req.nr_rx_rings) {
         num_cpus = netmap_descriptor->req.nr_rx_rings;
@@ -185,22 +178,20 @@ void receiver(std::string interface_for_listening) {
             logger.error("Ooops, main descriptor should be with NR_REG_ALL_NIC flag");
         }
 
-        nmd.req.nr_flags = NR_REG_ONE_NIC;
+        nmd.req.nr_flags  = NR_REG_ONE_NIC;
         nmd.req.nr_ringid = i;
 
         /* Only touch one of the rings (rx is already ok) */
         nmd_flags |= NETMAP_NO_TX_POLL;
 
-        struct nm_desc* new_nmd =
-        nm_open(interface.c_str(), NULL, nmd_flags | NM_OPEN_IFNAME | NM_OPEN_NO_MMAP, &nmd);
+        struct nm_desc* new_nmd = nm_open(interface.c_str(), NULL, nmd_flags | NM_OPEN_IFNAME | NM_OPEN_NO_MMAP, &nmd);
 
         if (new_nmd == NULL) {
             logger.error("Can't open netmap descriptor for netmap per hardware queue thread");
             return;
         }
 
-        logger.info("My first ring is %d and last ring id is %d I'm thread %d",
-                    new_nmd->first_rx_ring, new_nmd->last_rx_ring, i);
+        logger.info("My first ring is %d and last ring id is %d I'm thread %d", new_nmd->first_rx_ring, new_nmd->last_rx_ring, i);
 
 
         /*
@@ -212,7 +203,7 @@ void receiver(std::string interface_for_listening) {
 
         logger.info("Start new netmap thread %d", i);
 
-// Well, we have thread attributes from Boost 1.50
+        // Well, we have thread attributes from Boost 1.50
 
 #if defined(BOOST_THREAD_PLATFORM_PTHREAD) && BOOST_VERSION / 100 % 1000 >= 50 && !defined(__APPLE__) && defined(__GLIBC__)
         /* Bind to certain core */
@@ -229,8 +220,7 @@ void receiver(std::string interface_for_listening) {
 
             logger.info("I will bind this thread to logical CPU: %d", cpu_to_bind);
 
-            int set_affinity_result =
-            pthread_attr_setaffinity_np(thread_attrs.native_handle(), sizeof(cpu_set_t), &current_cpu_set);
+            int set_affinity_result = pthread_attr_setaffinity_np(thread_attrs.native_handle(), sizeof(cpu_set_t), &current_cpu_set);
 
             if (set_affinity_result != 0) {
                 logger.error("Can't specify CPU affinity for netmap thread");
@@ -238,8 +228,7 @@ void receiver(std::string interface_for_listening) {
         }
 
         // Start thread and pass netmap descriptor to it
-        packet_receiver_thread_group.add_thread(
-        new boost::thread(thread_attrs, boost::bind(netmap_thread, new_nmd, i)));
+        packet_receiver_thread_group.add_thread(new boost::thread(thread_attrs, boost::bind(netmap_thread, new_nmd, i)));
 #else
         logger.error("Sorry but CPU affinity did not supported for your platform");
         packet_receiver_thread_group.add_thread(new boost::thread(netmap_thread, new_nmd, i));
@@ -254,11 +243,11 @@ void netmap_thread(struct nm_desc* netmap_descriptor, int thread_number) {
     struct nm_pkthdr h;
     u_char* buf;
     struct pollfd fds;
-    fds.fd = netmap_descriptor->fd; // NETMAP_FD(netmap_descriptor);
+    fds.fd     = netmap_descriptor->fd; // NETMAP_FD(netmap_descriptor);
     fds.events = POLLIN;
 
     struct netmap_ring* rxring = NULL;
-    struct netmap_if* nifp = netmap_descriptor->nifp;
+    struct netmap_if* nifp     = netmap_descriptor->nifp;
 
     // printf("Reading from fd %d thread id: %d", netmap_descriptor->fd, thread_number);
 
@@ -287,7 +276,7 @@ void netmap_thread(struct nm_desc* netmap_descriptor, int thread_number) {
         }
 
         // TODO: this code could add performance degradation
-        // Add interruption point for correct toolkit shutdown 
+        // Add interruption point for correct toolkit shutdown
         // boost::this_thread::interruption_point();
     }
 
@@ -312,7 +301,8 @@ void start_netmap_collection(process_packet_pointer func_ptr) {
     }
 
     if (configuration_map.count("netmap_read_packet_length_from_ip_header") != 0) {
-        netmap_read_packet_length_from_ip_header = configuration_map["netmap_read_packet_length_from_ip_header"] == "on";
+        netmap_read_packet_length_from_ip_header =
+            configuration_map["netmap_read_packet_length_from_ip_header"] == "on";
     }
 
     std::vector<std::string> interfaces_for_listen;
@@ -324,11 +314,11 @@ void start_netmap_collection(process_packet_pointer func_ptr) {
     boost::thread_group netmap_main_threads;
 
     for (std::vector<std::string>::iterator interface = interfaces_for_listen.begin();
-        interface != interfaces_for_listen.end(); ++interface) {
+         interface != interfaces_for_listen.end(); ++interface) {
 
         logger << log4cpp::Priority::INFO << "netmap will sniff interface: " << *interface;
-        
-        netmap_main_threads.add_thread( new boost::thread(receiver, *interface) );
+
+        netmap_main_threads.add_thread(new boost::thread(receiver, *interface));
     }
 
     netmap_main_threads.join_all();
